@@ -9,13 +9,13 @@ import requests
 import re
 
 def getUrlContent(url, headers = {}):
-	headers['method'] = 'GET'
-	headers['accept'] = 'text/html,application/xhtml+xml,application/xml;q=0.9,image/apng,*/*;q=0.8,application/signed-exchange;v=b3'
-	headers['user-agent'] = 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/78.0.3904.97 Safari/537.36'
+	headers['method'] = headers.get('method', 'GET')
+	headers['accept'] = headers.get('accept', 'text/html,application/xhtml+xml,application/xml;q=0.9,image/apng,*/*;q=0.8,application/signed-exchange;v=b3')
+	headers['user-agent'] = headers.get('user-agent', 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/78.0.3904.97 Safari/537.36')
 	r = requests.get(url, headers=headers)
 	r.encoding = 'utf-8'
 	return r.text
-
+	
 def getFileName(url):
 	h = hashlib.sha224(url.encode('utf-8')).hexdigest()[:3]
 	k = re.sub(r'\W+', '', url.split('/')[-1].split('.')[0])[:10]
@@ -33,8 +33,8 @@ def cachedContent(url, headers = {}):
 			f.write(content)
 		return content
 
-def get(url, headers = {}):
-	if 'test' in str(sys.argv):
+def get(url, headers = {}, force_cache=False):
+	if force_cache or 'test' in str(sys.argv):
 		return cachedContent(url, headers)
 	else:
 		return getUrlContent(url, headers)
\ No newline at end of file
